@@ -1,27 +1,19 @@
-use 5.20.0;
+use 5.020;
 use strict;
 use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_11';
+  our $VERSION = '0.17_12';
 
   use Zydeco
     authority => 'cpan:SMONFF',
-    # Only possible since Type::Tiny->version 1.011000
-    # When Type::Tiny 1.011 came out, it started to be possible to remove quotes
-    # around the attributes types that are custom Zydeco classes of ours
-    #   has attr ( type => 'xxx' )
-    # See:
-    #   - https://rt.cpan.org/Public/Bug/Display.html?id=133448
-    #   - https://gitlab.com/smonff/art-world/-/issues/37
-    #
-    declare => [ 'Agent', 'Artwork', 'Collector', 'Theory', 'Idea'],
+    # Predeclaration of types avoid use of quotes https://gitlab.com/smonff/art-world/-/issues/37
+    declare => [ 'Agent', 'Artwork', 'Collector', 'Idea', 'Theory' ],
     version   => $VERSION;
-  if ( $] < 5.024 ) {
-    use feature "postderef";
-    no if ( $] >= 5.024 ), 'warnings' => 'experimental';
-  }
+
+  use feature qw( postderef );
+  no warnings qw( experimental::postderef );
   use Carp;
   use utf8;
   use Config::Tiny;
